@@ -13,7 +13,7 @@ use File::Which;
 use POSIX qw(SIGQUIT SIGKILL WNOHANG getuid setuid);
 use User::pwent;
 
-our $VERSION = '1.21';
+our $VERSION = '1.22';
 our $errstr;
 
 # Deprecate use of %Defaults as we want to remove this package global
@@ -106,7 +106,7 @@ has initdb_args => (
   isa => Str,
 );
 
-method _build_initdb_args {
+method _build_initdb_args() {
     return "-U postgres -A trust " . $self->extra_initdb_args;
 }
 
@@ -175,7 +175,7 @@ has postmaster_args => (
   isa => Str,
 );
 
-method _build_postmaster_args {
+method _build_postmaster_args() {
     return "-h 127.0.0.1 -F " . $self->extra_postmaster_args;
 }
 
